/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.inlong.sort.formats.common;

import org.apache.inlong.common.pojo.sort.dataflow.field.format.ArrayFormatInfo;
import org.apache.inlong.common.pojo.sort.dataflow.field.format.DateFormatInfo;
import org.apache.inlong.common.pojo.sort.dataflow.field.format.FloatFormatInfo;
import org.apache.inlong.common.pojo.sort.dataflow.field.format.FormatInfo;
import org.apache.inlong.common.pojo.sort.dataflow.field.format.MapFormatInfo;
import org.apache.inlong.common.pojo.sort.dataflow.field.format.StringFormatInfo;

import java.util.Arrays;
import java.util.Collection;

/**
 * Unit tests for {@link ArrayFormatInfo}.
 */
public class ArrayFormatInfoTest extends FormatInfoTestBase {

    @Override
    Collection<FormatInfo> createFormatInfos() {
        ArrayFormatInfo formatInfo1 =
                new ArrayFormatInfo(StringFormatInfo.INSTANCE);

        ArrayFormatInfo formatInfo2 =
                new ArrayFormatInfo(
                        new ArrayFormatInfo(new DateFormatInfo("YYYY-MM-DD")));

        ArrayFormatInfo formatInfo3 =
                new ArrayFormatInfo(
                        new MapFormatInfo(
                                StringFormatInfo.INSTANCE,
                                new ArrayFormatInfo(FloatFormatInfo.INSTANCE)));

        return Arrays.asList(formatInfo1, formatInfo2, formatInfo3);
    }
}
